summaryrefslogtreecommitdiffstats
path: root/kresources/egroupware/kcal_resourcexmlrpc.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/egroupware/kcal_resourcexmlrpc.cpp')
-rw-r--r--kresources/egroupware/kcal_resourcexmlrpc.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/kresources/egroupware/kcal_resourcexmlrpc.cpp b/kresources/egroupware/kcal_resourcexmlrpc.cpp
index 15864a374..6bbdc2342 100644
--- a/kresources/egroupware/kcal_resourcexmlrpc.cpp
+++ b/kresources/egroupware/kcal_resourcexmlrpc.cpp
@@ -250,7 +250,7 @@ bool ResourceXMLRPC::doLoad()
columns.insert( "type", "task" );
args.insert( "filter", "none" );
args.insert( "col_filter", columns );
- args.insert( "order", "id_parent" );
+ args.insert( "order", "id_tqparent" );
mServer->call( SearchTodosCommand, args,
this, TQT_SLOT( listTodosFinished( const TQValueList<TQVariant>&, const TQVariant& ) ),
@@ -651,7 +651,7 @@ void ResourceXMLRPC::loadEventCategoriesFinished( const TQValueList<TQVariant> &
for ( it = map.begin(); it != map.end(); ++it ) {
mEventCategoryMap.insert( it.data().toString(), it.key().toInt() );
- if ( prefs.mCustomCategories.find( it.data().toString() ) == prefs.mCustomCategories.end() )
+ if ( prefs.mCustomCategories.tqfind( it.data().toString() ) == prefs.mCustomCategories.end() )
prefs.mCustomCategories.append( it.data().toString() );
}
@@ -756,7 +756,7 @@ void ResourceXMLRPC::loadTodoCategoriesFinished( const TQValueList<TQVariant> &m
for ( it = map.begin(); it != map.end(); ++it ) {
mTodoCategoryMap.insert( it.data().toString(), it.key().toInt() );
- if ( prefs.mCustomCategories.find( it.data().toString() ) == prefs.mCustomCategories.end() )
+ if ( prefs.mCustomCategories.tqfind( it.data().toString() ) == prefs.mCustomCategories.end() )
prefs.mCustomCategories.append( it.data().toString() );
}
@@ -964,7 +964,7 @@ void ResourceXMLRPC::writeEvent( Event *event, TQMap<TQString, TQVariant> &args
TQMap<TQString, TQVariant> catMap;
int counter = 0;
for ( catIt = categories.begin(); catIt != categories.end(); ++catIt ) {
- TQMap<TQString, int>::Iterator it = mEventCategoryMap.find( *catIt );
+ TQMap<TQString, int>::Iterator it = mEventCategoryMap.tqfind( *catIt );
if ( it == mEventCategoryMap.end() ) // new category
catMap.insert( TQString::number( counter-- ), *catIt );
else
@@ -1099,7 +1099,7 @@ void ResourceXMLRPC::writeTodo( Todo* todo, TQMap<TQString, TQVariant>& args )
TQStringList::ConstIterator catIt;
int counter = 0;
for ( catIt = categories.begin(); catIt != categories.end(); ++catIt ) {
- TQMap<TQString, int>::Iterator it = mTodoCategoryMap.find( *catIt );
+ TQMap<TQString, int>::Iterator it = mTodoCategoryMap.tqfind( *catIt );
if ( it == mTodoCategoryMap.end() )
catMap.insert( TQString::number( counter-- ), *catIt );
else
@@ -1114,8 +1114,8 @@ void ResourceXMLRPC::writeTodo( Todo* todo, TQMap<TQString, TQVariant>& args )
// SUBTODO
Incidence *inc = todo->relatedTo();
if ( inc ) {
- TQString parentUid = idMapper().remoteId( inc->uid() );
- args.insert( "id_parent", parentUid );
+ TQString tqparentUid = idMapper().remoteId( inc->uid() );
+ args.insert( "id_tqparent", tqparentUid );
}
// STATE
@@ -1172,13 +1172,13 @@ void ResourceXMLRPC::readTodo( const TQMap<TQString, TQVariant>& args, Todo *tod
}
// SUBTODO
- TQString parentId = args[ "id_parent" ].toString();
- if ( parentId != "0" ) { // we are a sub todo
- TQString localParentUid = idMapper().localId( parentId );
- if ( !localParentUid.isEmpty() ) { // found parent todo
- Todo *parent = mCalendar.todo( localParentUid );
- if ( parent )
- todo->setRelatedTo( parent );
+ TQString tqparentId = args[ "id_tqparent" ].toString();
+ if ( tqparentId != "0" ) { // we are a sub todo
+ TQString localParentUid = idMapper().localId( tqparentId );
+ if ( !localParentUid.isEmpty() ) { // found tqparent todo
+ Todo *tqparent = mCalendar.todo( localParentUid );
+ if ( tqparent )
+ todo->setRelatedTo( tqparent );
}
}